<?php

namespace Drupal\content_freeze\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for checking whether content should be frozen.
 */
class FreezeContentController extends ControllerBase {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new FreezeContentController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, MessengerInterface $messenger) {
    $this->configFactory = $config_factory;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('messenger')
    );
  }

  /**
   * Controller callback to check whether content should be frozen.
   */
  public function checkFreezeContent() {
    $config = $this->configFactory->get('content_freeze.settings');
    $freezeDate = $config->get('freeze_date');

    // Check if the current date is greater than or equal to the freeze date.
    $currentDate = new \DateTime();
    $freezeDate = new \DateTime($freezeDate);

    if ($currentDate >= $freezeDate) {
      $this->messenger->addMessage($this->t('Content editing is frozen.'), 'error');
    }
    else {
      $this->messenger->addMessage($this->t('Content editing is allowed.'), 'status');
    }

    return new Response();
  }

}
