<?php

namespace Drupal\content_freeze\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a form to configure Custom Freeze Content settings.
 */
class ContentFreezeSettingsForm extends ConfigFormBase {
  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * {@inheritdoc}
   */
  public function __construct(MessengerInterface $messenger) {
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['content_freeze.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_freeze_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_freeze.settings');
    $default_date = date('Y-m-d');

    $form['freeze_date'] = [
      '#type' => 'date',
      '#title' => $this->t('Freeze Content Date'),
      '#default_value' => $config->get('freeze_date'),
      '#attributes' => [
        'min' => $default_date,
      ],
    ];

    $form['reset_date'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset to Default'),
      '#submit' => ['::resetDate'],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Check which button was clicked.
    $clicked_button = $form_state->getTriggeringElement();

    if ($clicked_button['#type'] === 'submit' && $clicked_button['#name'] === 'op') {
      $this->config('content_freeze.settings')
        ->set('freeze_date', $form_state->getValue('freeze_date'))
        ->save();
      parent::submitForm($form, $form_state);
    }
    else {
      $this->resetDate($form, $form_state);
    }
  }

  /**
   * Submit handler to reset the date to the default value.
   */
  public function resetDate(array &$form, FormStateInterface $form_state) {
    $this->config('content_freeze.settings')
      ->set('freeze_date', '')
      ->save();
    $this->messenger->addStatus('The configuration options have been saved.');
  }

}
